@@ -1,7 +1,7 @@
 package Perinci::CmdLine;
 
-our $DATE = '2014-12-02'; # DATE
-our $VERSION = '1.39'; # VERSION
+our $DATE = '2014-12-11'; # DATE
+our $VERSION = '1.40'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -18,9 +18,9 @@ our $REQ_VERSION = 0; # version requested by user
 
 extends 'Perinci::CmdLine::Base';
 
-with 'SHARYANTO::Role::ColorTheme' unless $ENV{COMP_LINE};
-#with 'SHARYANTO::Role::TermAttrs' unless $ENV{COMP_LINE}; already loaded by ColorTheme
+with 'Color::Theme::Role::ANSI' unless $ENV{COMP_LINE};
 with 'Perinci::CmdLine::Role::Help' unless $ENV{COMP_LINE};
+with 'Term::App::Role::Attrs' unless $ENV{COMP_LINE};
 
 has log => (is => 'rw', default=>sub{1});
 has undo => (is=>'rw', default=>sub{0});
@@ -859,7 +859,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.39 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2014-12-02.
+This document describes version 1.40 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2014-12-11.
 
 =head1 SYNOPSIS
 
@@ -911,8 +911,8 @@ L</"LOGGING"> for more details.
 
 =head2 use_utf8 => BOOL
 
-From L<SHARYANTO::Role::TermAttrs> (please see its docs for more details). There
-are several other attributes added by the role.
+From L<Term::App::Role::Attrs> (please see its docs for more details). There are
+several other attributes added by the role.
 
 =head2 undo => BOOL (optional, default 0)
 
@@ -976,11 +976,11 @@ Explicitly turn the progress bar on/off.
 
 =head2 COLOR => INT
 
-Please see L<SHARYANTO::Role::TermAttrs>.
+Please see L<Term::App::Role::Attrs>.
 
 =head2 UTF8 => BOOL
 
-Please see L<SHARYANTO::Role::TermAttrs>.
+Please see L<Term::App::Role::Attrs>.
 
 =head1 SEE ALSO
 
